//	NPBTutorialDialog.cpp - Displays a text file in a DialogWindow.
//----------------------------------------------------------------------------
//	This file is part of 'Niall's Pedal Board', a simple ASIO VST host.
//	Copyright (C) 2004-2005  Niall Moody
//	
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//	
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//	
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//	
//----------------------------------------------------------------------------
//
//	You can e-mail me at niallmoody@yahoo.co.uk if you want.
//
//----------------------------------------------------------------------------

#include <juce.h>
#include "NPBTutorialDialog.h"

//----------------------------------------------------------------------------
NPBTutorialDialog::NPBTutorialDialog(Colour col, String path):
DialogWindow(T("Tutorial"), col)
{
	int tempint;

	tempint = path.lastIndexOf(".");
	setName(path.dropLastCharacters(path.length() - tempint).fromLastOccurrenceOf("\\", false, false));

	Viewport *view = new Viewport();
	NPBTutorialDialogContent *cont = new NPBTutorialDialogContent(col, path);
	view->setViewedComponent(cont);
	setContentComponent(view);
	setVisible(true);
	setResizable(true, false);
}

//----------------------------------------------------------------------------
NPBTutorialDialogContent::NPBTutorialDialogContent(Colour col, String path):
Component(),
backColour(col)
{
	setVisible(true);
	setSize(370, 250);
	parseTextFile(convertRelativePath(path));
}

//----------------------------------------------------------------------------
void NPBTutorialDialogContent::paint(Graphics& g)
{
	SolidColourBrush brush(backColour);
	g.setBrush(&brush);
	g.fillAll();
}

//----------------------------------------------------------------------------
void NPBTutorialDialogContent::parseTextFile(String path)
{
	int i;
	int y = 0;
	String tempstr1;
	String tempstr2;
	int maxWidth;
	Label *templab;
	Image *tempim1;
	StaticImage *tempim2;
	Font tempFont(16.0f);
	File phil(path);

	tempstr1 = phil.loadFileAsString();

	for(i=0;i<tempstr1.length();i++)
	{
		//This is kind of bad, but we'll assume there are only ever <img=...>
		//tags in the file...
		if(tempstr1[i] == '<')
		{
			//If it's not empty, write the contents of tempstr2 to a Label.
			if(tempstr2.isNotEmpty())
			{
				templab = new DontStripTheWhitespaceLabel(T("tempLabel"),
														  tempstr2);
				addAndMakeVisible(templab);
				templab->setFont(tempFont);
				templab->setTopLeftPosition(5, y);
				templab->setSize((tempFont.getStringWidth(tempstr2)+10), 15);
				y += 17;
			}

			i += 5;
			tempstr2 = String::empty;
			while(tempstr1[i] != '>')
			{
				tempstr2 += tempstr1[i];
				i++;
			}
			tempim1 = ImageCache::getFromFile(File(convertRelativePath(tempstr2)));
			tempim2 = new StaticImage(tempim1);
			addAndMakeVisible(tempim2);
			tempim2->setTopLeftPosition(5, y);
			y += tempim2->getHeight() + 2;

			tempstr2 = String::empty;
		}
		//Write the contents of tempstr2 to a Label, add it to the window.
		else if(tempstr1[i] == '\n')
		{
			if(tempstr2.isNotEmpty())
			{
				templab = new DontStripTheWhitespaceLabel(T("tempLabel"),
														  tempstr2);
				addAndMakeVisible(templab);
				templab->setFont(tempFont);
				templab->setTopLeftPosition(5, y);
				templab->setSize((tempFont.getStringWidth(tempstr2)+10), 15);
				y += 17;

				tempstr2 = String::empty;
			}
		}
		else
			tempstr2 += tempstr1[i];
	}

	maxWidth = 0;
	for(i=0;i<getNumChildComponents();i++)
	{
		if(getChildComponent(i)->getWidth() > maxWidth)
			maxWidth = getChildComponent(i)->getWidth();
	}

	setSize(maxWidth, (y+2));
}

///---------------------------------------------------------------------------
DontStripTheWhitespaceLabel::DontStripTheWhitespaceLabel(const String &componentName,
														 const String &labelText):
Label(componentName, labelText)
{
	
}

///---------------------------------------------------------------------------
void DontStripTheWhitespaceLabel::paint(Graphics& g)
{
	//Have had to hack out all the useful parts of this, because the useful
	//variables are all private members, and no get() methods are provided
	//for them (*sigh*).  As such, this whole class is an ugly hack, and
	//would be unnecessary if drawFittedText didn't strip whitespace from
	//Strings that aren't even too long...

	//g.fillAll(backgroundColour);

	const float alpha = isEnabled() ? 1.0f : 0.5f;
	Font tempFont(16.0f);

	g.setColour(Colours::black);
	g.setFont(tempFont);
	//g.drawFittedText(text, 3, 1, getWidth() - 6, getHeight() - 2, justification, 1);
	g.drawText(getText(),
			   3,
			   1,
			   (getWidth()-6),
			   (getHeight()-2),
			   Justification::centredLeft,
			   false);
}

///---------------------------------------------------------------------------
String convertRelativePath(String path)
{
	int i;
	String tempstr;
	String tempdir; //have to do some tricks to get the application directory...

	//this is to handle absolute file paths
#ifdef WIN32
	if(path[1] == T(':'))
		return path;
#else
	if(path[0] == T('/'))
		return path;
#endif

	tempdir = File::getCurrentApplicationFile().getFullPathName();
	for(i=(tempdir.length()-1);i>=0;i--)
	{
		if(tempdir[i] == File::separator)
			break;
	}
	tempstr = tempdir.substring(0, (i+1));

	tempstr += path;
	return tempstr;
}
