///	MainWindow.cpp - 'Dummy' subclass of FactoryObject, to set various aspects
///				      of the main window.
///	--------------------------------------------------------------------------
///	This file is part of 'Niall's Pedal Board', a simple ASIO VST host.
///	Copyright (C) 2005  Niall Moody
///	
///	This program is free software; you can redistribute it and/or modify
///	it under the terms of the GNU General Public License as published by
///	the Free Software Foundation; either version 2 of the License, or
///	(at your option) any later version.
///	
///	This program is distributed in the hope that it will be useful,
///	but WITHOUT ANY WARRANTY; without even the implied warranty of
///	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
///	GNU General Public License for more details.
///	
///	You should have received a copy of the GNU General Public License
///	along with this program; if not, write to the Free Software
///	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
///	
///	--------------------------------------------------------------------------
///	
///	You can e-mail me at niallmoody@yahoo.co.uk if you want.
///	
///	--------------------------------------------------------------------------


#include "../NPBWindow.h"
#include "MainWindow.h"
#include "../ComponentFactory.h"

///---------------------------------------------------------------------------
MainWindow::MainWindow(ComponentFactory *factory, Component **windowComponent):
FactoryObject(factory, windowComponent)
{
	//Register this object with the factory.
	factory->registerObject(this, String("mainWindow"));

	//Register all it's attributes with the factory.
	factory->registerBoolAttribute(this, String("resizeable"), &MainWindow::setResizeable);
	factory->registerBoolAttribute(this, String("maximise"), &MainWindow::setMaximise);
	factory->registerIntAttribute(this, String("colour_red"), &MainWindow::setColourRed);
	factory->registerIntAttribute(this, String("colour_green"), &MainWindow::setColourGreen);
	factory->registerIntAttribute(this, String("colour_blue"), &MainWindow::setColourBlue);
	factory->registerBoolAttribute(this, String("dropShadow"), &MainWindow::setDropShadow);
	factory->registerBoolAttribute(this, String("centre"), &MainWindow::setCentre);
	factory->registerStringAttribute(this, String("title"), &MainWindow::setTitle);
	factory->registerIntAttribute(this, String("title_red"), &MainWindow::setTitleColourRed);
	factory->registerIntAttribute(this, String("title_green"), &MainWindow::setTitleColourGreen);
	factory->registerIntAttribute(this, String("title_blue"), &MainWindow::setTitleColourBlue);
	factory->registerIntAttribute(this, String("title_x"), &MainWindow::setTitleX);
	factory->registerIntAttribute(this, String("title_y"), &MainWindow::setTitleY);
	factory->registerIntAttribute(this, String("lookAndFeel"), &MainWindow::setLookAndFeel);
}

///---------------------------------------------------------------------------
void MainWindow::setResizeable(bool val)
{
	NPBWindow *window;

	window = static_cast<NPBWindow *>(factory->getWindow());
	window->setResizer(val);
}

///---------------------------------------------------------------------------
void MainWindow::setMaximise(bool val)
{
	NPBWindow *window;

	if(val) //don't need to set it if it's false (it'll already be alright)
	{
		window = static_cast<NPBWindow *>(factory->getWindow());
		window->setMaximise(val);
	}
}

///---------------------------------------------------------------------------
void MainWindow::setColourRed(int val)
{
	NPBWindow *window;

	window = static_cast<NPBWindow *>(factory->getWindow());
	window->setColourRed(val);
}

///---------------------------------------------------------------------------
void MainWindow::setColourGreen(int val)
{
	NPBWindow *window;

	window = static_cast<NPBWindow *>(factory->getWindow());
	window->setColourGreen(val);
}

///---------------------------------------------------------------------------
void MainWindow::setColourBlue(int val)
{
	NPBWindow *window;

	window = static_cast<NPBWindow *>(factory->getWindow());
	window->setColourBlue(val);
}

///---------------------------------------------------------------------------
void MainWindow::setDropShadow(bool val)
{
	NPBWindow *window;

	if(!val) //because drop shadow's on by default
	{
		window = static_cast<NPBWindow *>(factory->getWindow());
		window->removeFromDesktop();
		window->addToDesktop(Component::windowAppearsOnTaskbar);
	}
}

///---------------------------------------------------------------------------
void MainWindow::setCentre(bool val)
{
	NPBWindow *window;

	if(val)
	{
		window = static_cast<NPBWindow *>(factory->getWindow());
		window->centreWithSize(window->getWidth(), window->getHeight());
	}
}

///---------------------------------------------------------------------------
void MainWindow::setTitle(String val)
{
	Component *tempcomp;

	tempcomp = factory->getWindow();

	tempcomp->setName(val);
}

///---------------------------------------------------------------------------
void MainWindow::setTitleColourRed(int val)
{
	NPBWindow *window;

	window = static_cast<NPBWindow *>(factory->getWindow());
	window->setTitleColourRed(val);
}

///---------------------------------------------------------------------------
void MainWindow::setTitleColourGreen(int val)
{
	NPBWindow *window;

	window = static_cast<NPBWindow *>(factory->getWindow());
	window->setTitleColourGreen(val);
}

///---------------------------------------------------------------------------
void MainWindow::setTitleColourBlue(int val)
{
	NPBWindow *window;

	window = static_cast<NPBWindow *>(factory->getWindow());
	window->setTitleColourBlue(val);
}

///---------------------------------------------------------------------------
void MainWindow::setTitleX(int val)
{
	NPBWindow *window;

	window = static_cast<NPBWindow *>(factory->getWindow());
	window->setTitleX(val);
}

///---------------------------------------------------------------------------
void MainWindow::setTitleY(int val)
{
	NPBWindow *window;

	window = static_cast<NPBWindow *>(factory->getWindow());
	window->setTitleY(val);
}

///---------------------------------------------------------------------------
void MainWindow::setLookAndFeel(int val)
{
	NPBWindow *window;

	window = static_cast<NPBWindow *>(factory->getWindow());
	window->setLAndF(val);
}

///---------------------------------------------------------------------------
void MainWindow::setX(int val)
{
	Component *tempcomp;

	tempcomp = factory->getWindow();

	tempcomp->setTopLeftPosition(val, tempcomp->getY());
}

///---------------------------------------------------------------------------
void MainWindow::setY(int val)
{
	Component *tempcomp;

	tempcomp = factory->getWindow();

	tempcomp->setTopLeftPosition(tempcomp->getX(), val);
}

///---------------------------------------------------------------------------
void MainWindow::setXRel(double val)
{
	int tempint;
	Component *tempcomp;

	tempcomp = factory->getWindow();

	tempint = static_cast<int>((val/100.0)*static_cast<double>(tempcomp->getWidth()));
	tempcomp->setTopLeftPosition(tempint, tempcomp->getY());
}

///---------------------------------------------------------------------------
void MainWindow::setYRel(double val)
{
	int tempint;
	Component *tempcomp;

	tempcomp = factory->getWindow();

	tempint = static_cast<int>((val/100.0)*static_cast<double>(tempcomp->getHeight()));
	tempcomp->setTopLeftPosition(tempcomp->getX(), tempint);
}

///---------------------------------------------------------------------------
void MainWindow::setWidth(int val)
{
	Component *tempcomp;

	tempcomp = factory->getWindow();

	tempcomp->setSize(val, tempcomp->getHeight());
}

///---------------------------------------------------------------------------
void MainWindow::setHeight(int val)
{
	Component *tempcomp;

	tempcomp = factory->getWindow();

	tempcomp->setSize(tempcomp->getWidth(), val);
}

///---------------------------------------------------------------------------
void MainWindow::setWidthRel(double val)
{
	int tempint;
	Component *tempcomp;

	tempcomp = factory->getWindow();

	tempint = static_cast<int>((val/100.0)*static_cast<double>(tempcomp->getWidth()));
	tempcomp->setSize(tempint, tempcomp->getHeight());
}

///---------------------------------------------------------------------------
void MainWindow::setHeightRel(double val)
{
	int tempint;
	Component *tempcomp;

	tempcomp = factory->getWindow();

	tempint = static_cast<int>((val/100.0)*static_cast<double>(tempcomp->getHeight()));
	tempcomp->setSize(tempcomp->getWidth(), tempint);
}
